@@ -1,16 +1,19 @@
 from .metadata import MetadataFields, Metadata
-from .playlist import PlaybackMode
+from .playlist import PlaybackMode, PlaylistRepeatMode, PlaylistShuffleMode
 from .base_player import State
 from .mpvplayer import MpvPlayer as Player
 from .playlist import PlaylistMode, Playlist
 from .fm import FM
 from .radio import SongRadio
-from .lyric import LiveLyric, parse_lyric_text
+from .lyric import LiveLyric, parse_lyric_text, Line as LyricLine, Lyric
 from .recently_played import RecentlyPlayed
+from .delegate import PlayerPositionDelegate
 
 
 __all__ = (
     'PlaybackMode',
+    'PlaylistRepeatMode',
+    'PlaylistShuffleMode',
     'State',
 
     'FM',
@@ -19,12 +22,15 @@ __all__ = (
 
     'Player',
     'Playlist',
+    'PlayerPositionDelegate',
 
     'Metadata',
     'MetadataFields',
 
     'LiveLyric',
     'parse_lyric_text',
+    'LyricLine',
+    'Lyric',
 
     'RecentlyPlayed',
 )
